=== modified symlink 'hooks/ceph-client-relation-broken'
=== target changed 'hooks.py' => 'hooks'
=== modified symlink 'hooks/ceph-client-relation-changed'
=== target changed 'hooks.py' => 'hooks'
=== modified symlink 'hooks/ceph-client-relation-departed'
=== target changed 'hooks.py' => 'hooks'
=== modified symlink 'hooks/ceph-client-relation-joined'
=== target changed 'hooks.py' => 'hooks'
=== modified file 'hooks/common.py'
--- hooks/common.py	2016-12-14 16:08:39 +0000
+++ hooks/common.py	2018-02-24 05:26:59 +0000
@@ -8,11 +8,18 @@
 from charmhelpers.core.hookenv import (
     log, local_unit, status_set)
 
-from landscape.configuration import (
-    setup, register, LandscapeSetupConfiguration, ConfigurationError,
-    stop_client_and_disable_init_script)
-from landscape.deployment import Configuration
-from landscape.sysvconfig import SysVConfig
+try:
+    from landscape.client.configuration import (
+        setup, register, LandscapeSetupConfiguration, ConfigurationError,
+        stop_client_and_disable_init_script)
+    from landscape.client.deployment import Configuration
+    from landscape.client.sysvconfig import SysVConfig
+except ImportError:
+    from landscape.configuration import (
+        setup, register, LandscapeSetupConfiguration, ConfigurationError,
+        stop_client_and_disable_init_script)
+    from landscape.deployment import Configuration
+    from landscape.sysvconfig import SysVConfig
 
 
 class JujuBroker(object):

=== modified symlink 'hooks/config-changed'
=== target changed 'hooks.py' => 'hooks'
=== modified symlink 'hooks/container-relation-departed'
=== target changed 'hooks.py' => 'hooks'
=== modified symlink 'hooks/container-relation-joined'
=== target changed 'hooks.py' => 'hooks'
=== added file 'hooks/hooks'
--- hooks/hooks	1970-01-01 00:00:00 +0000
+++ hooks/hooks	2018-02-24 05:26:59 +0000
@@ -0,0 +1,11 @@
+#!/bin/sh
+
+hooks_py="`dirname $0`/hooks.py"
+interpreter="/usr/bin/python"
+
+if [ `lsb_release -rs` \> "18.00" ]; then
+    # landscape-client has py3 libs from bionic forward
+    interpreter="/usr/bin/python3"
+fi
+
+exec ${interpreter} ${hooks_py} $0 $@

=== modified file 'hooks/hooks.py'
--- hooks/hooks.py	2017-10-19 09:44:44 +0000
+++ hooks/hooks.py	2018-02-24 05:26:59 +0000
@@ -1,11 +1,10 @@
-#!/usr/bin/python
-
 import apt_pkg
 import sys
 import socket
 import os
 import base64
 
+import six
 from charmhelpers.core.hookenv import (
     Hooks, UnregisteredHookError, log)
 from shutil import rmtree
@@ -54,7 +53,7 @@
         install_landscape_client(service_config["origin"], fetch=fetch)
     # Only update client config with service configs that have been set
     set_config = {}
-    for key, value in service_config.iteritems():
+    for key, value in six.iteritems(service_config):
         if value is not None:
             if type(value) == str:
                 set_config[key] = value.strip()
@@ -188,7 +187,7 @@
                     "juju-private-address": None}
     juju_info = dict.fromkeys(key for key in juju_key_map.values() if key)
     files_to_delete = []
-    for filename, info_key in juju_key_map.iteritems():
+    for filename, info_key in six.iteritems(juju_key_map):
         file_path = os.path.join(meta_data_dir, filename)
         if not os.path.exists(file_path):
             continue
@@ -221,6 +220,6 @@
 
 if __name__ == '__main__':
     try:
-        sys.exit(hooks.execute(sys.argv))
+        sys.exit(hooks.execute(sys.argv[1:]))
     except UnregisteredHookError as e:
         log('Unknown hook {} - skipping.'.format(e))

=== modified symlink 'hooks/registration-relation-changed'
=== target changed 'hooks.py' => 'hooks'
=== modified symlink 'hooks/registration-relation-departed'
=== target changed 'hooks.py' => 'hooks'
=== modified symlink 'hooks/registration-relation-joined'
=== target changed 'hooks.py' => 'hooks'
=== modified file 'hooks/test_hooks.py'
--- hooks/test_hooks.py	2017-03-03 10:16:05 +0000
+++ hooks/test_hooks.py	2018-02-24 05:26:59 +0000
@@ -6,6 +6,7 @@
 from unittest import TestCase
 from uuid import uuid4
 
+import six
 from landscape.deployment import Configuration
 from landscape.lib.fs import read_file
 import hooks
@@ -105,7 +106,7 @@
         super(MigrateOldJujuInfoTest, self).setUp()
 
     def setup_old_juju_info(self, juju_info):
-        for filename, contents in juju_info.iteritems():
+        for filename, contents in six.iteritems(juju_info):
             juju_path = os.path.join(self.config.meta_data_path, filename)
             with open(juju_path, "w") as juju_file:
                 juju_file.write(contents)

=== modified symlink 'hooks/upgrade-charm'
=== target changed 'hooks.py' => 'hooks'
=== modified file 'metadata.yaml'
--- metadata.yaml	2016-12-14 16:04:54 +0000
+++ metadata.yaml	2018-02-24 05:26:59 +0000
@@ -10,6 +10,7 @@
 series:
   - trusty
   - xenial
+  - bionic
 tags: [ ops, monitoring ]
 requires:
   container:

